@@ -147,6 +147,7 @@ enum {
    CI_BADBATTS,                    /* Number of bad battery packs */
    CI_EPROM,                       /* Valid eprom values */
    CI_ST_TIME,                     /* hours since last self test */
+   CI_TESTALARM,                   /* Test alarm */
    CI_Manufacturer,             
    CI_ShutdownRequested,        
    CI_ShutdownImminent,         
@@ -174,6 +175,9 @@ enum {
    CI_APCLineFailCause,         
    CI_NOMINV,                   
    CI_NOMPOWER,
+   CI_LowBattery,
+   CI_Calibration,
+   CI_AlarmTimer,
 
    /* Only seen on the BackUPS Pro USB (so far) */
    CI_BUPBattCapBeforeStartup,  
