@@ -219,6 +219,7 @@ extern void wait_for_termination(int serial_pid);
 extern void log_event(const UPSINFO *ups, int level, const char *fmt, ...);
 extern void logf(const char *fmt, ...);
 extern void hex_dump(int level, void *data, unsigned int len);
+extern int format_date(time_t timestamp, char *dest, size_t destlen);
 
 /* In apcnetlib.c */
 extern int net_open(const char *host, char *service, int port);
@@ -254,4 +255,11 @@ int winioctl(int fd, int func, int *addr);
   int nanosleep(const struct timespec *req, struct timespec *rem);
 #endif
 
+/*
+ * Common interface to the various versions of gethostbyname_r().
+ * Implemented in gethostname.c.
+ */
+struct hostent * gethostname_re
+    (const char *host,struct hostent *hostbuf,char **tmphstbuf,size_t *hstbuflen);
+
 #endif   /* _EXTERN_H */
