@@ -1,6 +1,6 @@
 #define DEBUG 1
-#define VERSION "3.14.6"
-#define ADATE   "16 May 2009"
+#define VERSION "3.14.8"
+#define ADATE   "16 January 2010"
 
 #define APCUPSD_RELEASE VERSION
 
