@@ -263,7 +263,7 @@ int main(int argc, char *argv[])
    ups->start_time = time(NULL);
    delete_lockfile(ups);
 
-   if (!kill_ups_power && go_background) {
+   if (!hibernate_ups && !shutdown_ups && go_background) {
       daemon_start();
 
       /* Reopen log file, closed during becoming daemon */
@@ -273,8 +273,8 @@ int main(int argc, char *argv[])
    make_pid_file();
    init_signals(apcupsd_terminate);
 
-   /* Create temp events file if we are not doing a killpower */
-   if (!kill_ups_power && ups->eventfile[0] != 0) {
+   /* Create temp events file if we are not doing a hibernate or shutdown */
+   if (!hibernate_ups && !shutdown_ups && ups->eventfile[0] != 0) {
       ups->event_fd = open(ups->eventfile, O_RDWR | O_CREAT | O_APPEND, 0644);
       if (ups->event_fd < 0) {
          log_event(ups, LOG_WARNING, "Could not open events file %s: %s\n",
@@ -284,8 +284,13 @@ int main(int argc, char *argv[])
 
    setup_device(ups);
 
-   if (kill_ups_power) {
-      kill_power(ups);
+   if (hibernate_ups) {
+      initiate_hibernate(ups);
+      apcupsd_terminate(0);
+   }
+   
+   if (shutdown_ups) {
+      initiate_shutdown(ups);
       apcupsd_terminate(0);
    }
 
@@ -310,7 +315,7 @@ int main(int argc, char *argv[])
       Dmsg0(10, "NIS thread started.\n");
    }
 
-   log_event(ups, LOG_INFO,
+   log_event(ups, LOG_WARNING,
       "apcupsd " APCUPSD_RELEASE " (" ADATE ") " APCUPSD_HOST " startup succeeded");
 
    /* main processing loop */
@@ -333,6 +338,7 @@ static void daemon_start(void)
    pid_t cpid;
    mode_t oldmask;
 
+#ifndef HAVE_QNX_OS
    if ((cpid = fork()) < 0)
       Error_abort0("Cannot fork to become daemon\n");
    else if (cpid > 0)
@@ -340,6 +346,15 @@ static void daemon_start(void)
 
    /* Child continues */
    setsid();                       /* become session leader */
+#else
+   if (procmgr_daemon(EXIT_SUCCESS, PROCMGR_DAEMON_NOCHDIR
+                                    | PROCMGR_DAEMON_NOCLOSE
+                                    | PROCMGR_DAEMON_NODEVNULL
+                                    | PROCMGR_DAEMON_KEEPUMASK) == -1)
+   {
+      Error_abort0("Couldn't become daemon\n");
+   }
+#endif   /* HAVE_QNX_OS */
 
    /* Call closelog() to close syslog file descriptor */
    closelog();
