@@ -137,6 +137,8 @@ char *smart_poll(char cmd, UPSINFO *ups)
    int stat, retry;
 
    *answer = 0;
+   if (ups->fd == -1)
+      return answer;
    if (ups->mode.type <= SHAREBASIC)
       return answer;
 
@@ -157,6 +159,11 @@ char *smart_poll(char cmd, UPSINFO *ups)
    return answer;
 }
 
+int writechar(char a, UPSINFO *ups)
+{
+  return write(ups->fd, &a, 1);
+}
+
 /*
  * If s == NULL we are just waiting on FD for status changes.
  * If s != NULL we are asking the UPS to tell us the value of something.
@@ -209,6 +216,8 @@ int getline(char *s, int len, UPSINFO *ups)
       case -1:
          if (errno == EINTR || errno == EAGAIN) {       /* assume SIGCHLD */
             continue;
+         } else if (errno == EBADF) {
+            return FAILURE;               /* We're probably shutting down */
          }
          Error_abort1("Select error on UPS FD. %s\n", strerror(errno));
          break;
@@ -592,10 +601,10 @@ int apcsmart_ups_read_volatile_data(UPSINFO *ups)
       ups->LastSTTime = atof(answer);
    }
 
-   write_unlock(ups);
-
    apc_enable(ups);                /* reenable APC serial UPS */
 
+   write_unlock(ups);
+
    return SUCCESS;
 }
 
