@@ -574,12 +574,7 @@ int pcnet_ups_check_state(UPSINFO *ups)
       /* Ensure the packet is nul-terminated */
       buf[retval] = '\0';
 
-      if (debug_level >= 300) {
-         logf("Interrupt data: ");
-         for (int i = 0; i <= retval; i++)
-            logf("%02x, ", buf[i]);
-         logf("\n");
-      }
+      hex_dump(300, buf, retval);
 
       map = auth_and_map_packet(ups, buf, retval);
       if (map == NULL)
