@@ -65,6 +65,7 @@ const struct s_known_info known_info[] = {
    {CI_VLINE,                   0x00840030, P_INPUT,   T_UNITS,    true },  /* Line Voltage */
    {CI_VOUT,                    0x00840030, P_OUTPUT,  T_UNITS,    true },  /* Output Voltage */
    {CI_VBATT,                   0x00840030, P_BATTERY, T_UNITS,    true },  /* Battery Voltage */
+   {CI_VBATT,                   0x00840030, P_PWSUM,   T_UNITS,    true },  /* Battery Voltage (alternative) */
    {CI_NONE,                    0x00840031, P_ANY,     T_UNITS,    false},  /* Current */
    {CI_FREQ,                    0x00840032, P_OUTPUT,  T_UNITS,    true },  /* Frequency */
    {CI_NONE,                    0x00840033, P_ANY,     T_UNITS,    false},  /* ApparentPower */
@@ -74,6 +75,7 @@ const struct s_known_info known_info[] = {
    {CI_ATEMP,                   0x00840036, P_APC1,    T_UNITS,    true },  /* Ambient Temperature */
    {CI_HUMID,                   0x00840037, P_ANY,     T_UNITS,    true },  /* Humidity */
    {CI_NOMBATTV,                0x00840040, P_BATTERY, T_UNITS,    false},  /* ConfigVoltage (battery) */
+   {CI_NOMBATTV,                0x00840040, P_PWSUM,   T_UNITS,    false},  /* ConfigVoltage (battery, alternate) */
    {CI_NOMOUTV,                 0x00840040, P_OUTPUT,  T_UNITS,    false},  /* ConfigVoltage (output) */
    {CI_NOMINV,                  0x00840040, P_INPUT,   T_UNITS,    false},  /* ConfigVoltage (input) */
    {CI_NONE,                    0x00840042, P_ANY,     T_UNITS,    false},  /* ConfigFrequency */
@@ -138,12 +140,14 @@ const struct s_known_info known_info[] = {
 
    /*  Pages 0xFF00 to 0xFFFF are vendor specific */
    /* CI                        USAGE       PHYS       TYPE        VOLATILE? */
+   {CI_STESTI,                  0xFF86001a, P_ANY,     T_NONE,     false},  /* APCSelfTestInterval */
    {CI_STATUS,                  0xFF860060, P_ANY,     T_BITS,     true },  /* APCStatusFlag */
    {CI_DSHUTD,                  0xFF860076, P_ANY,     T_UNITS,    false},  /* APCShutdownAfterDelay */
    {CI_NONE,                    0xFF860005, P_ANY,     T_NONE,     false},  /* APCGeneralCollection */
    {CI_APCForceShutdown,        0xFF86007C, P_ANY,     T_NONE,     false},  /* APCForceShutdown */
-   {CI_NONE,                    0xFF860072, P_ANY,     T_NONE,     false},  /* APCPanelTest */
-   {CI_BattReplaceDate,         0xFF860016, P_ANY,     T_APCDATE,  false},  /* APCBattReplaceDate */
+   {CI_TESTALARM,               0xFF860072, P_ANY,	    T_NONE,     false},  /* APCTestAlarm */
+// Removed the below due to all recent UPSes having the same garbage in this field
+// {CI_BattReplaceDate,         0xFF860016, P_ANY,     T_APCDATE,  false},  /* APCBattReplaceDate */
    {CI_NONE,                    0xFF860042, P_ANY,     T_NONE,     false},  /* APC_UPS_FirmwareRevision */
    {CI_NONE,                    0xFF860079, P_ANY,     T_NONE,     false},  /* APC_USB_FirmwareRevision */
    {CI_RETPCT,                  0xFF860019, P_ANY,     T_CAPACITY, false},  /* APCBattCapBeforeStartup */
@@ -547,6 +551,24 @@ static void usb_process_value(UPSINFO* ups, int ci, USB_VALUE* uval)
       }
       break;
 
+   /* Self test interval */
+   case CI_STESTI:
+      switch (uval->iValue) {
+      case 0:
+         astrncpy(ups->selftest, "None", sizeof(ups->selftest));
+         break;
+      case 1:
+         astrncpy(ups->selftest, "Power On", sizeof(ups->selftest));
+         break;
+      case 2:
+         astrncpy(ups->selftest, "7 days", sizeof(ups->selftest));
+         break;
+      default:
+         astrncpy(ups->selftest, "14 days", sizeof(ups->selftest));
+         break;
+      }
+      break;
+
    /* Reason for last xfer to battery */
    case CI_APCLineFailCause:
       Dmsg1(100, "CI_APCLineFailCause=%d\n", uval->iValue);
