@@ -19,7 +19,7 @@
 //
 // Author          : Christopher S. Hull
 // Created On      : Sat Jan 31 15:55:00 2004
-// $Id: compat.cpp,v 1.22.2.2 2008/06/21 21:04:15 adk0212 Exp $
+// $Id: compat.cpp,v 1.22.2.3 2009/07/31 14:20:35 adk0212 Exp $
 
 #include "apc.h"
 #include "compat.h"
@@ -458,43 +458,6 @@ gettimeofday(struct timeval *tv, struct timezone *)
 
 }
 
-/*
- * Dotted IP address to network address
- *
- * Returns 1 if  OK
- *         0 on error
- */
-int
-inet_aton(const char *a, struct in_addr *inp)
-{
-   const char *cp = a;
-   uint32_t acc = 0, tmp = 0;
-   int dotc = 0;
-
-   if (!isdigit(*cp)) {         /* first char must be digit */
-      return 0;                 /* error */
-   }
-   do {
-      if (isdigit(*cp)) {
-         tmp = (tmp * 10) + (*cp -'0');
-      } else if (*cp == '.' || *cp == 0) {
-         if (tmp > 255) {
-            return 0;           /* error */
-         }
-         acc = (acc << 8) + tmp;
-         dotc++;
-         tmp = 0;
-      } else {
-         return 0;              /* error */
-      }
-   } while (*cp++ != 0);
-   if (dotc != 4) {              /* want 3 .'s plus EOS */
-      return 0;                  /* error */
-   }
-   inp->s_addr = htonl(acc);     /* store addr in network format */
-   return 1;
-}
-
 void
 init_signals(void terminate(int sig))
 {
@@ -522,24 +485,6 @@ pathconf(const char *path, int name)
     return -1;
 }
 
-int
-WSA_Init(void)
-{
-    WORD wVersionRequested = MAKEWORD( 1, 1);
-    WSADATA wsaData;
-
-    int err = WSAStartup(wVersionRequested, &wsaData);
-
-
-    if (err != 0) {
-        printf("Can not start Windows Sockets\n");
-        errno = ENOSYS;
-        return -1;
-    }
-
-    return 0;
-}
-
 int
 kill(int pid, int signal)
 {
